@@ -34,6 +34,65 @@ class TestPyfitsHDUListFunctions(unittest.TestCase):
         except:
             pass
 
+    def testUpdateName(self):
+        hdul=pyfits.open(test_dir+'o4sp040b0_raw.fits')
+        hdul[4].update_ext_name('Jim', "added by Jim")
+        hdul[4].update_ext_version(9, "added by Jim")
+        self.assertEqual(hdul[('JIM',9)].header['extname'], 'JIM')
+
+    def testHDUFileBytes(self):
+        hdul = pyfits.open(test_dir+'checksum.fits')
+        res = hdul[0].filebytes()
+        self.assertEqual(res, 11520)
+        res = hdul[1].filebytes()
+        self.assertEqual(res,8640)
+
+    def testHDUListFileInfo(self):
+        hdul = pyfits.open(test_dir+'checksum.fits')
+        res = hdul.fileinfo(0)
+        self.assertEqual(res['datSpan'], 2880)
+        self.assertEqual(res['resized'], 0)
+        self.assertEqual(res['filename'], test_dir+'checksum.fits')
+        self.assertEqual(res['datLoc'], 8640)
+        self.assertEqual(res['hdrLoc'], 0)
+        self.assertEqual(res['filemode'], 'copyonwrite')
+
+        res = hdul.fileinfo(1)
+        self.assertEqual(res['datSpan'], 2880)
+        self.assertEqual(res['resized'], 0)
+        self.assertEqual(res['filename'], test_dir+'checksum.fits')
+        self.assertEqual(res['datLoc'], 17280)
+        self.assertEqual(res['hdrLoc'], 11520)
+        self.assertEqual(res['filemode'], 'copyonwrite')
+
+        hdu = pyfits.ImageHDU(data=hdul[0].data)
+        hdul.insert(1,hdu)
+
+        res = hdul.fileinfo(0)
+        self.assertEqual(res['datSpan'], 2880)
+        self.assertEqual(res['resized'], 1)
+        self.assertEqual(res['filename'], test_dir+'checksum.fits')
+        self.assertEqual(res['datLoc'], 8640)
+        self.assertEqual(res['hdrLoc'], 0)
+        self.assertEqual(res['filemode'], 'copyonwrite')
+
+        res = hdul.fileinfo(1)
+        self.assertEqual(res['datSpan'], None)
+        self.assertEqual(res['resized'], 1)
+        self.assertEqual(res['filename'], test_dir+'checksum.fits')
+        self.assertEqual(res['datLoc'], None)
+        self.assertEqual(res['hdrLoc'], None)
+        self.assertEqual(res['filemode'], 'copyonwrite')
+
+        res = hdul.fileinfo(2)
+        self.assertEqual(res['datSpan'], 2880)
+        self.assertEqual(res['resized'], 1)
+        self.assertEqual(res['filename'], test_dir+'checksum.fits')
+        self.assertEqual(res['datLoc'], 17280)
+        self.assertEqual(res['hdrLoc'], 11520)
+        self.assertEqual(res['filemode'], 'copyonwrite')
+
+
     def testAppendPrimaryToEmptyList(self):
         # Tests appending a Simple PrimaryHDU to an empty HDUList.
         hdul = pyfits.HDUList()
