@@ -40,6 +40,10 @@ class TestPyfitsImageFunctions(unittest.TestCase):
         except:
             pass
 
+        try:
+            os.remove(jfile)
+        except:
+            pass
 
     def testCardConstructorDefaultArgs(self):
         # Test the constructor with default argument values.
@@ -79,15 +83,15 @@ class TestPyfitsImageFunctions(unittest.TestCase):
         # floating point number
         c=pyfits.Card('floatnum', -467374636747637647347374734737437.)
 
-        if str(c) != "FLOATNUM= -4.673746367476376E+32                                                " and str(c) != "FLOATNUM= -4.673746367476376E+032                                               ":
-            self.assertEqual(str(c),"FLOATNUM= -4.673746367476376E+32                                                ")
+        if str(c) != "FLOATNUM= -4.6737463674763E+32                                                  " and str(c) != "FLOATNUM= -4.6737463674763E+032                                                 ":
+            self.assertEqual(str(c),"FLOATNUM= -4.6737463674763E+32                                                  ")
 
     def testComplexValue(self):
         # complex value
         c=pyfits.Card('abc',1.2345377437887837487e88+6324767364763746367e-33j)
 
-        if str(c) != "ABC     = (1.234537743788784E+88, 6.324767364763747E-15)                        " and str(c) != "ABC     = (1.234537743788784E+088, 6.324767364763747E-015)                      ":
-            self.assertEqual(str(c),"ABC     = (1.234537743788784E+88, 6.324767364763747E-15)                        ")
+        if str(c) != "ABC     = (1.23453774378878E+88, 6.32476736476374E-15)                          " and str(c) != "ABC     = (1.2345377437887E+088, 6.3247673647637E-015)                          ":
+            self.assertEqual(str(c),"ABC     = (1.23453774378878E+88, 6.32476736476374E-15)                          ")
 
     def testCardImageConstructedTooLong(self):
         tmpfile = open(jfile,'w')
@@ -270,6 +274,13 @@ CONTINUE  '&' / ntlongcommentlongcommentlongcommentlongcomment
 CONTINUE  'ampersand at the endcontinue must have string value (with quotes)&'  \
 CONTINUE  '&' / comments in line 1 comments with ''.                            ")
 
+    def testHierarchCard(self):
+        c = pyfits.Card('hierarch abcdefghi',10)
+        self.assertEqual(str(c.ascardimage()),"HIERARCH abcdefghi = 10                                                         ")
+        c = pyfits.Card('HIERARCH ESO INS SLIT2 Y1FRML', 'ENC=OFFSET+RESOL*acos((WID-(MAX+MIN))/(MAX-MIN)')
+        self.assertEqual(str(c.ascardimage()),"HIERARCH ESO INS SLIT2 Y1FRML= 'ENC=OFFSET+RESOL*acos((WID-(MAX+MIN))/(MAX-MIN)'")
+
+
     def testOpen(self):
         # The function "open" reads a FITS file into an HDUList object.  There are
         # three modes to open: "readonly" (the default), "append", and "update".
@@ -499,19 +510,10 @@ CONTINUE  '&' / comments in line 1 comments with ''.
                                                                      [352, 353, 354]]).all())
 
 
-        try:
-            fs[0].section[3,2:5,:8]
-            x = "Did not fail as expected."
-        except IndexError:
-            x = "Failed as expected."
-        self.assertEqual(x,"Failed as expected.")
+        dat=fs[0].data
+        self.assertEqual(fs[0].section[3,2:5,:8].all(), dat[3,2:5,:8].all())
+        self.assertEqual(fs[0].section[3,2:5,3].all(), dat[3,2:5,3].all())
 
-        try:
-            fs[0].section[3,2:5,3]
-            x = "Did not fail as expected."
-        except IndexError:
-            x = "Failed as expected."
-        self.assertEqual(x,"Failed as expected.")
 
         self.assertEqual(fs[0].section[3:6,:,:][:3,:3,:3].all(),np.array([[[330, 331, 332],
                                                                      [341, 342, 343],
@@ -534,33 +536,201 @@ CONTINUE  '&' / comments in line 1 comments with ''.
                                                                          [[220, 221],
                                                                           [231, 232]]]).all())
 
-        try:
-            fs[0].section[:,2,:]
-            x = "Did not fail as expected."
-        except IndexError:
-            x = "Failed as expected."
-        self.assertEqual(x,"Failed as expected.")
+        self.assertEqual(fs[0].section[:,2,:].all(), dat[:,2,:].all())
+        self.assertEqual(fs[0].section[:,2:5,:].all(), dat[:,2:5,:].all())
+        self.assertEqual(fs[0].section[3:6,3,:].all(), dat[3:6,3,:].all())
+        self.assertEqual(fs[0].section[3:6,3:7,:].all(), dat[3:6,3:7,:].all())
 
-        try:
-            fs[0].section[:,2:5,:]
-            x = "Did not fail as expected."
-        except IndexError:
-            x = "Failed as expected."
-        self.assertEqual(x,"Failed as expected.")
+    def testSectionDataSquare(self):
+        a=np.arange(4).reshape((2,2))
+        hdu = pyfits.PrimaryHDU(a)
+        hdu.writeto(jfile)
 
-        try:
-            fs[0].section[3:6,3,:]
-            x = "Did not fail as expected."
-        except IndexError:
-            x = "Failed"
-        self.assertEqual(x,"Failed")
+        hdul=pyfits.open(jfile)
+        d = hdul[0]
+        dat = hdul[0].data
+        self.assertEqual(d.section[:,:].all(), dat[:,:].all())
+        self.assertEqual(d.section[0,:].all(), dat[0,:].all())
+        self.assertEqual(d.section[1,:].all(), dat[1,:].all())
+        self.assertEqual(d.section[:,0].all(), dat[:,0].all())
+        self.assertEqual(d.section[:,1].all(), dat[:,1].all())
+        self.assertEqual(d.section[0,0].all(), dat[0,0].all())
+        self.assertEqual(d.section[0,1].all(), dat[0,1].all())
+        self.assertEqual(d.section[1,0].all(), dat[1,0].all())
+        self.assertEqual(d.section[1,1].all(), dat[1,1].all())
+        self.assertEqual(d.section[0:1,0:1].all(), dat[0:1,0:1].all())
+        self.assertEqual(d.section[0:2,0:1].all(), dat[0:2,0:1].all())
+        self.assertEqual(d.section[0:1,0:2].all(), dat[0:1,0:2].all())
+        self.assertEqual(d.section[0:2,0:2].all(), dat[0:2,0:2].all())
+        os.remove(jfile)
+
+    def testSectionDataCube(self):
+        a=np.arange(18).reshape((2,3,3))
+        hdu = pyfits.PrimaryHDU(a)
+        hdu.writeto(jfile)
+
+        hdul=pyfits.open(jfile)
+        d = hdul[0]
+        dat = hdul[0].data
+        self.assertEqual(d.section[:,:,:].all(), dat[:,:,:].all())
+        self.assertEqual(d.section[:,:].all(), dat[:,:].all())
+        self.assertEqual(d.section[:].all(), dat[:].all())
+        self.assertEqual(d.section[0,:,:].all(), dat[0,:,:].all())
+        self.assertEqual(d.section[1,:,:].all(), dat[1,:,:].all())
+        self.assertEqual(d.section[0,0,:].all(), dat[0,0,:].all())
+        self.assertEqual(d.section[0,1,:].all(), dat[0,1,:].all())
+        self.assertEqual(d.section[0,2,:].all(), dat[0,2,:].all())
+        self.assertEqual(d.section[1,0,:].all(), dat[1,0,:].all())
+        self.assertEqual(d.section[1,1,:].all(), dat[1,1,:].all())
+        self.assertEqual(d.section[1,2,:].all(), dat[1,2,:].all())
+        self.assertEqual(d.section[0,0,0].all(), dat[0,0,0].all())
+        self.assertEqual(d.section[0,0,1].all(), dat[0,0,1].all())
+        self.assertEqual(d.section[0,0,2].all(), dat[0,0,2].all())
+        self.assertEqual(d.section[0,1,0].all(), dat[0,1,0].all())
+        self.assertEqual(d.section[0,1,1].all(), dat[0,1,1].all())
+        self.assertEqual(d.section[0,1,2].all(), dat[0,1,2].all())
+        self.assertEqual(d.section[0,2,0].all(), dat[0,2,0].all())
+        self.assertEqual(d.section[0,2,1].all(), dat[0,2,1].all())
+        self.assertEqual(d.section[0,2,2].all(), dat[0,2,2].all())
+        self.assertEqual(d.section[1,0,0].all(), dat[1,0,0].all())
+        self.assertEqual(d.section[1,0,1].all(), dat[1,0,1].all())
+        self.assertEqual(d.section[1,0,2].all(), dat[1,0,2].all())
+        self.assertEqual(d.section[1,1,0].all(), dat[1,1,0].all())
+        self.assertEqual(d.section[1,1,1].all(), dat[1,1,1].all())
+        self.assertEqual(d.section[1,1,2].all(), dat[1,1,2].all())
+        self.assertEqual(d.section[1,2,0].all(), dat[1,2,0].all())
+        self.assertEqual(d.section[1,2,1].all(), dat[1,2,1].all())
+        self.assertEqual(d.section[1,2,2].all(), dat[1,2,2].all())
+        self.assertEqual(d.section[:,0,0].all(), dat[:,0,0].all())
+        self.assertEqual(d.section[:,0,1].all(), dat[:,0,1].all())
+        self.assertEqual(d.section[:,0,2].all(), dat[:,0,2].all())
+        self.assertEqual(d.section[:,1,0].all(), dat[:,1,0].all())
+        self.assertEqual(d.section[:,1,1].all(), dat[:,1,1].all())
+        self.assertEqual(d.section[:,1,2].all(), dat[:,1,2].all())
+        self.assertEqual(d.section[:,2,0].all(), dat[:,2,0].all())
+        self.assertEqual(d.section[:,2,1].all(), dat[:,2,1].all())
+        self.assertEqual(d.section[:,2,2].all(), dat[:,2,2].all())
+        self.assertEqual(d.section[0,:,0].all(), dat[0,:,0].all())
+        self.assertEqual(d.section[0,:,1].all(), dat[0,:,1].all())
+        self.assertEqual(d.section[0,:,2].all(), dat[0,:,2].all())
+        self.assertEqual(d.section[1,:,0].all(), dat[1,:,0].all())
+        self.assertEqual(d.section[1,:,1].all(), dat[1,:,1].all())
+        self.assertEqual(d.section[1,:,2].all(), dat[1,:,2].all())
+        self.assertEqual(d.section[:,:,0].all(), dat[:,:,0].all())
+        self.assertEqual(d.section[:,:,1].all(), dat[:,:,1].all())
+        self.assertEqual(d.section[:,:,2].all(), dat[:,:,2].all())
+        self.assertEqual(d.section[:,0,:].all(), dat[:,0,:].all())
+        self.assertEqual(d.section[:,1,:].all(), dat[:,1,:].all())
+        self.assertEqual(d.section[:,2,:].all(), dat[:,2,:].all())
+
+        self.assertEqual(d.section[:,:,0:1].all(), dat[:,:,0:1].all())
+        self.assertEqual(d.section[:,:,0:2].all(), dat[:,:,0:2].all())
+        self.assertEqual(d.section[:,:,0:3].all(), dat[:,:,0:3].all())
+        self.assertEqual(d.section[:,:,1:2].all(), dat[:,:,1:2].all())
+        self.assertEqual(d.section[:,:,1:3].all(), dat[:,:,1:3].all())
+        self.assertEqual(d.section[:,:,2:3].all(), dat[:,:,2:3].all())
+        self.assertEqual(d.section[0:1,0:1,0:1].all(), dat[0:1,0:1,0:1].all())
+        self.assertEqual(d.section[0:1,0:1,0:2].all(), dat[0:1,0:1,0:2].all())
+        self.assertEqual(d.section[0:1,0:1,0:3].all(), dat[0:1,0:1,0:3].all())
+        self.assertEqual(d.section[0:1,0:1,1:2].all(), dat[0:1,0:1,1:2].all())
+        self.assertEqual(d.section[0:1,0:1,1:3].all(), dat[0:1,0:1,1:3].all())
+        self.assertEqual(d.section[0:1,0:1,2:3].all(), dat[0:1,0:1,2:3].all())
+        self.assertEqual(d.section[0:1,0:2,0:1].all(), dat[0:1,0:2,0:1].all())
+        self.assertEqual(d.section[0:1,0:2,0:2].all(), dat[0:1,0:2,0:2].all())
+        self.assertEqual(d.section[0:1,0:2,0:3].all(), dat[0:1,0:2,0:3].all())
+        self.assertEqual(d.section[0:1,0:2,1:2].all(), dat[0:1,0:2,1:2].all())
+        self.assertEqual(d.section[0:1,0:2,1:3].all(), dat[0:1,0:2,1:3].all())
+        self.assertEqual(d.section[0:1,0:2,2:3].all(), dat[0:1,0:2,2:3].all())
+        self.assertEqual(d.section[0:1,0:3,0:1].all(), dat[0:1,0:3,0:1].all())
+        self.assertEqual(d.section[0:1,0:3,0:2].all(), dat[0:1,0:3,0:2].all())
+        self.assertEqual(d.section[0:1,0:3,0:3].all(), dat[0:1,0:3,0:3].all())
+        self.assertEqual(d.section[0:1,0:3,1:2].all(), dat[0:1,0:3,1:2].all())
+        self.assertEqual(d.section[0:1,0:3,1:3].all(), dat[0:1,0:3,1:3].all())
+        self.assertEqual(d.section[0:1,0:3,2:3].all(), dat[0:1,0:3,2:3].all())
+        self.assertEqual(d.section[0:1,1:2,0:1].all(), dat[0:1,1:2,0:1].all())
+        self.assertEqual(d.section[0:1,1:2,0:2].all(), dat[0:1,1:2,0:2].all())
+        self.assertEqual(d.section[0:1,1:2,0:3].all(), dat[0:1,1:2,0:3].all())
+        self.assertEqual(d.section[0:1,1:2,1:2].all(), dat[0:1,1:2,1:2].all())
+        self.assertEqual(d.section[0:1,1:2,1:3].all(), dat[0:1,1:2,1:3].all())
+        self.assertEqual(d.section[0:1,1:2,2:3].all(), dat[0:1,1:2,2:3].all())
+        self.assertEqual(d.section[0:1,1:3,0:1].all(), dat[0:1,1:3,0:1].all())
+        self.assertEqual(d.section[0:1,1:3,0:2].all(), dat[0:1,1:3,0:2].all())
+        self.assertEqual(d.section[0:1,1:3,0:3].all(), dat[0:1,1:3,0:3].all())
+        self.assertEqual(d.section[0:1,1:3,1:2].all(), dat[0:1,1:3,1:2].all())
+        self.assertEqual(d.section[0:1,1:3,1:3].all(), dat[0:1,1:3,1:3].all())
+        self.assertEqual(d.section[0:1,1:3,2:3].all(), dat[0:1,1:3,2:3].all())
+        self.assertEqual(d.section[1:2,0:1,0:1].all(), dat[1:2,0:1,0:1].all())
+        self.assertEqual(d.section[1:2,0:1,0:2].all(), dat[1:2,0:1,0:2].all())
+        self.assertEqual(d.section[1:2,0:1,0:3].all(), dat[1:2,0:1,0:3].all())
+        self.assertEqual(d.section[1:2,0:1,1:2].all(), dat[1:2,0:1,1:2].all())
+        self.assertEqual(d.section[1:2,0:1,1:3].all(), dat[1:2,0:1,1:3].all())
+        self.assertEqual(d.section[1:2,0:1,2:3].all(), dat[1:2,0:1,2:3].all())
+        self.assertEqual(d.section[1:2,0:2,0:1].all(), dat[1:2,0:2,0:1].all())
+        self.assertEqual(d.section[1:2,0:2,0:2].all(), dat[1:2,0:2,0:2].all())
+        self.assertEqual(d.section[1:2,0:2,0:3].all(), dat[1:2,0:2,0:3].all())
+        self.assertEqual(d.section[1:2,0:2,1:2].all(), dat[1:2,0:2,1:2].all())
+        self.assertEqual(d.section[1:2,0:2,1:3].all(), dat[1:2,0:2,1:3].all())
+        self.assertEqual(d.section[1:2,0:2,2:3].all(), dat[1:2,0:2,2:3].all())
+        self.assertEqual(d.section[1:2,0:3,0:1].all(), dat[1:2,0:3,0:1].all())
+        self.assertEqual(d.section[1:2,0:3,0:2].all(), dat[1:2,0:3,0:2].all())
+        self.assertEqual(d.section[1:2,0:3,0:3].all(), dat[1:2,0:3,0:3].all())
+        self.assertEqual(d.section[1:2,0:3,1:2].all(), dat[1:2,0:3,1:2].all())
+        self.assertEqual(d.section[1:2,0:3,1:3].all(), dat[1:2,0:3,1:3].all())
+        self.assertEqual(d.section[1:2,0:3,2:3].all(), dat[1:2,0:3,2:3].all())
+        self.assertEqual(d.section[1:2,1:2,0:1].all(), dat[1:2,1:2,0:1].all())
+        self.assertEqual(d.section[1:2,1:2,0:2].all(), dat[1:2,1:2,0:2].all())
+        self.assertEqual(d.section[1:2,1:2,0:3].all(), dat[1:2,1:2,0:3].all())
+        self.assertEqual(d.section[1:2,1:2,1:2].all(), dat[1:2,1:2,1:2].all())
+        self.assertEqual(d.section[1:2,1:2,1:3].all(), dat[1:2,1:2,1:3].all())
+        self.assertEqual(d.section[1:2,1:2,2:3].all(), dat[1:2,1:2,2:3].all())
+        self.assertEqual(d.section[1:2,1:3,0:1].all(), dat[1:2,1:3,0:1].all())
+        self.assertEqual(d.section[1:2,1:3,0:2].all(), dat[1:2,1:3,0:2].all())
+        self.assertEqual(d.section[1:2,1:3,0:3].all(), dat[1:2,1:3,0:3].all())
+        self.assertEqual(d.section[1:2,1:3,1:2].all(), dat[1:2,1:3,1:2].all())
+        self.assertEqual(d.section[1:2,1:3,1:3].all(), dat[1:2,1:3,1:3].all())
+        self.assertEqual(d.section[1:2,1:3,2:3].all(), dat[1:2,1:3,2:3].all())
+
+        os.remove(jfile)
+
+    def testSectionDataFour(self):
+        a=np.arange(256).reshape((4,4,4,4))
+        hdu = pyfits.PrimaryHDU(a)
+        hdu.writeto(jfile)
+
+        hdul=pyfits.open(jfile)
+        d=hdul[0]
+        dat = hdul[0].data
+        self.assertEqual(d.section[:,:,:,:].all(), dat[:,:,:,:].all())
+        self.assertEqual(d.section[:,:,:].all(), dat[:,:,:].all())
+        self.assertEqual(d.section[:,:].all(), dat[:,:].all())
+        self.assertEqual(d.section[:].all(), dat[:].all())
+        self.assertEqual(d.section[0,:,:,:].all(), dat[0,:,:,:].all())
+        self.assertEqual(d.section[0,:,0,:].all(), dat[0,:,0,:].all())
+        self.assertEqual(d.section[:,:,0,:].all(), dat[:,:,0,:].all())
+        self.assertEqual(d.section[:,1,0,:].all(), dat[:,1,0,:].all())
+        self.assertEqual(d.section[:,:,:,1].all(), dat[:,:,:,1].all())
+
+        os.remove(jfile)
+
+    def testCompImage(self):
+        data = np.zeros((2, 10, 10), dtype=np.float32)
+        primary_hdu = pyfits.PrimaryHDU()
+        ofd = pyfits.HDUList(primary_hdu)
+        ofd.append(pyfits.CompImageHDU(data, name="SCI",
+                                       compressionType="GZIP_1",
+                                       quantizeLevel=-0.01))
+        ofd.writeto(jfile)
+        ofd.close()
+        fd = pyfits.open (jfile)
+        self.assertEqual(fd[1].data.all(), data.all())
+        os.remove(jfile)
+
+    def testDoNotScaleImageData(self):
+        hdul = pyfits.open(test_dir+'scale.fits',do_not_scale_image_data=True)
+        self.assertEqual(hdul[0].data.dtype,np.dtype('>i2'))
+        hdul = pyfits.open(test_dir+'scale.fits')
+        self.assertEqual(hdul[0].data.dtype,np.dtype('float32'))
 
-        try:
-            fs[0].section[3:6,3:7,:]
-            x = "Did not fail."
-        except IndexError:
-            x = "Failed again"
-        self.assertEqual(x,"Failed again")
 
 if __name__ == '__main__':
     unittest.main()
