@@ -1,4 +1,4 @@
-/* $Id: fits_hcompress.c 423 2009-03-25 17:58:53Z jtaylor2 $
+/* $Id: fits_hcompress.c 682 2010-09-16 15:24:59Z stsci_jtaylor2 $
 */
 
 /*****************************************************************************/
@@ -147,8 +147,8 @@ static void output_nnybble(char *outfile, int n, unsigned char array[]);
 #define output_huffman(outfile,c)	output_nbits(outfile,code[c],ncode[c])
 
 /* ---------------------------------------------------------------------- */
-int fits_hcompress(int *a, int ny, int nx, int scale, char *output, 
-                  long *nbytes, int *status)
+int _pyfits_fits_hcompress(int *a, int ny, int nx, int scale, char *output, 
+                           long *nbytes, int *status)
 {
   /* 
      compress the input image using the H-compress algorithm
@@ -193,8 +193,8 @@ int fits_hcompress(int *a, int ny, int nx, int scale, char *output,
   return(*status);
 }
 /* ---------------------------------------------------------------------- */
-int fits_hcompress64(LONGLONG *a, int ny, int nx, int scale, char *output, 
-                  long *nbytes, int *status)
+int _pyfits_fits_hcompress64(LONGLONG *a, int ny, int nx, int scale,
+                  char *output, long *nbytes, int *status)
 {
   /* 
      compress the input image using the H-compress algorithm
@@ -269,7 +269,7 @@ int *tmp;
 	 */
 	tmp = (int *) malloc(((nmax+1)/2)*sizeof(int));
 	if(tmp == (int *) NULL) {
-	        ffpmsg("htrans: insufficient memory");
+	        _pyfits_ffpmsg("htrans: insufficient memory");
 		return(DATA_COMPRESSION_ERR);
 	}
 	/*
@@ -405,7 +405,7 @@ LONGLONG *tmp;
 	 */
 	tmp = (LONGLONG *) malloc(((nmax+1)/2)*sizeof(LONGLONG));
 	if(tmp == (LONGLONG *) NULL) {
-	        ffpmsg("htrans64: insufficient memory");
+	        _pyfits_ffpmsg("htrans64: insufficient memory");
 		return(DATA_COMPRESSION_ERR);
 	}
 	/*
@@ -699,7 +699,7 @@ int stat;
 	 */
 	signbits = (unsigned char *) malloc((nel+7)/8);
 	if (signbits == (unsigned char *) NULL) {
-		ffpmsg("encode: insufficient memory");
+		_pyfits_ffpmsg("encode: insufficient memory");
 		return(DATA_COMPRESSION_ERR);
 	}
 	nsign = 0;
@@ -790,7 +790,7 @@ int stat;
 	 */
 	if (0 == qwrite(outfile, (char *) nbitplanes, sizeof(nbitplanes))) {
 	        *nlength = noutchar;
-		ffpmsg("encode: output buffer too small");
+		_pyfits_ffpmsg("encode: output buffer too small");
 		return(DATA_COMPRESSION_ERR);
         }
 	 
@@ -807,7 +807,7 @@ int stat;
 	   if ( 0 == qwrite(outfile, (char *) signbits, nsign)) {
 	        free(signbits);
 	        *nlength = noutchar;
-		ffpmsg("encode: output buffer too small");
+		_pyfits_ffpmsg("encode: output buffer too small");
 		return(DATA_COMPRESSION_ERR);
           }
 	} 
@@ -816,7 +816,7 @@ int stat;
 	*nlength = noutchar;
 
         if (noutchar >= noutmax) {
-		ffpmsg("encode: output buffer too small");
+		_pyfits_ffpmsg("encode: output buffer too small");
 		return(DATA_COMPRESSION_ERR);
         }  
 	
@@ -860,7 +860,7 @@ int stat;
 	 */
 	signbits = (unsigned char *) malloc((nel+7)/8);
 	if (signbits == (unsigned char *) NULL) {
-		ffpmsg("encode64: insufficient memory");
+		_pyfits_ffpmsg("encode64: insufficient memory");
 		return(DATA_COMPRESSION_ERR);
 	}
 	nsign = 0;
@@ -952,7 +952,7 @@ int stat;
 
 	if (0 == qwrite(outfile, (char *) nbitplanes, sizeof(nbitplanes))) {
 	        *nlength = noutchar;
-		ffpmsg("encode: output buffer too small");
+		_pyfits_ffpmsg("encode: output buffer too small");
 		return(DATA_COMPRESSION_ERR);
         }
 	 
@@ -969,7 +969,7 @@ int stat;
 	   if ( 0 == qwrite(outfile, (char *) signbits, nsign)) {
 	        free(signbits);
 	        *nlength = noutchar;
-		ffpmsg("encode: output buffer too small");
+		_pyfits_ffpmsg("encode: output buffer too small");
 		return(DATA_COMPRESSION_ERR);
           }
 	} 
@@ -978,7 +978,7 @@ int stat;
 	*nlength = noutchar;
 
         if (noutchar >= noutmax) {
-		ffpmsg("encode64: output buffer too small");
+		_pyfits_ffpmsg("encode64: output buffer too small");
 		return(DATA_COMPRESSION_ERR);
         }
 		
@@ -1381,7 +1381,7 @@ unsigned char *scratch, *buffer;
 	buffer = (unsigned char *) malloc(bmax);
 	if ((scratch == (unsigned char *) NULL) ||
 		(buffer  == (unsigned char *) NULL)) {
-		ffpmsg("qtree_encode: insufficient memory");
+		_pyfits_ffpmsg("qtree_encode: insufficient memory");
 		return(DATA_COMPRESSION_ERR);
 	}
 	/*
@@ -1500,7 +1500,7 @@ unsigned char *scratch, *buffer;
 	buffer = (unsigned char *) malloc(bmax);
 	if ((scratch == (unsigned char *) NULL) ||
 		(buffer  == (unsigned char *) NULL)) {
-		ffpmsg("qtree_encode64: insufficient memory");
+		_pyfits_ffpmsg("qtree_encode64: insufficient memory");
 		return(DATA_COMPRESSION_ERR);
 	}
 	/*
