@@ -1,4 +1,4 @@
-/* $Id: quantize.c 442 2009-04-22 12:43:13Z jtaylor2 $
+/* $Id: quantize.c 682 2010-09-16 15:24:59Z stsci_jtaylor2 $
 */
 
 /*****************************************************************************/
@@ -129,7 +129,8 @@ static short quick_select_short(short arr[], int n);
 static int quick_select_int(int arr[], int n);
 static double quick_select_double(double arr[], int n);
 /*---------------------------------------------------------------------------*/
-int fits_quantize_float (float fdata[], long nxpix, long nypix, int nullcheck, 
+int _pyfits_fits_quantize_float (float fdata[], long nxpix, long nypix,
+        int nullcheck, 
 	float in_null_value, float qlevel, int idata[], double *bscale,
 	double *bzero, int *iminval, int *imaxval) {
 
@@ -323,7 +324,8 @@ If the function value is zero, the data were not copied to idata.
 	return (1);			/* yes, data have been quantized */
 }
 /*---------------------------------------------------------------------------*/
-int fits_quantize_double (double fdata[], long nxpix, long nypix, int nullcheck, 
+int _pyfits_fits_quantize_double (double fdata[], long nxpix, long nypix,
+        int nullcheck, 
 	double in_null_value, float qlevel, int idata[], double *bscale,
 	double *bzero, int *iminval, int *imaxval) {
 
@@ -519,7 +521,8 @@ If the function value is zero, the data were not copied to idata.
 	return (1);			/* yes, data have been quantized */
 }
 /*--------------------------------------------------------------------------*/
-int fits_img_stats_short(short *array, /*  2 dimensional array of image pixels */
+static int fits_img_stats_short(
+        short *array, /*  2 dimensional array of image pixels */
         long nx,            /* number of pixels in each row of the image */
 	long ny,            /* number of rows in the image */
 	                    /* (if this is a 3D image, then ny should be the */
@@ -574,7 +577,8 @@ int fits_img_stats_short(short *array, /*  2 dimensional array of image pixels *
 	return(*status);
 }
 /*--------------------------------------------------------------------------*/
-int fits_img_stats_int(int *array, /*  2 dimensional array of image pixels */
+int _pyfits_fits_img_stats_int(
+        int *array, /*  2 dimensional array of image pixels */
         long nx,            /* number of pixels in each row of the image */
 	long ny,            /* number of rows in the image */
 	                    /* (if this is a 3D image, then ny should be the */
@@ -629,7 +633,8 @@ int fits_img_stats_int(int *array, /*  2 dimensional array of image pixels */
 	return(*status);
 }
 /*--------------------------------------------------------------------------*/
-int fits_img_stats_float(float *array, /*  2 dimensional array of image pixels */
+static int fits_img_stats_float(
+        float *array, /*  2 dimensional array of image pixels */
         long nx,            /* number of pixels in each row of the image */
 	long ny,            /* number of rows in the image */
 	                    /* (if this is a 3D image, then ny should be the */
